@@ -23,7 +23,7 @@ ${this}: download chezmoi and optionally run chezmoi
 Usage: ${this} [-b bindir] [-d] [-t tag] [chezmoi-args]
 	-b	sets the installation directory, default is ${BINDIR}.
 	-d	enables debug logging.
-	-t	sets the tag, default is ${TAG}.
+	-t	sets the tag, default is ${TAGARG}.
 If chezmoi-args are given, after install chezmoi is executed with chezmoi-args.
 EOF
 	exit 2
@@ -178,7 +178,6 @@ check_goos_goarch() {
 	openbsd/riscv64) return 0 ;;
 	windows/386) return 0 ;;
 	windows/amd64) return 0 ;;
-	windows/arm) return 0 ;;
 	*)
 		printf '%s: unsupported platform\n' "${1}" 1>&2
 		return 1
