@@ -25,5 +25,9 @@ func (c *Config) newEditConfigCmd() *cobra.Command {
 }
 
 func (c *Config) runEditConfigCmd(cmd *cobra.Command, args []string) error {
-	return c.runEditor([]string{c.getConfigFileAbsPath().String()})
+	configFileAbsPath, err := c.getConfigFileAbsPath()
+	if err != nil {
+		return err
+	}
+	return c.runEditor([]string{configFileAbsPath.String()})
 }
